@@ -6,7 +6,7 @@ import (
 	"unicode/utf8"
 
 	log "github.com/sirupsen/logrus"
-	"github.com/walles/moor/twin"
+	"github.com/walles/moor/v2/twin"
 )
 
 type SearchDirection int
