@@ -3,10 +3,10 @@ package internal
 import (
 	"fmt"
 
-	"github.com/walles/moor/internal/linemetadata"
-	"github.com/walles/moor/internal/reader"
-	"github.com/walles/moor/internal/textstyles"
-	"github.com/walles/moor/twin"
+	"github.com/walles/moor/v2/internal/linemetadata"
+	"github.com/walles/moor/v2/internal/reader"
+	"github.com/walles/moor/v2/internal/textstyles"
+	"github.com/walles/moor/v2/twin"
 )
 
 type renderedLine struct {
