@@ -278,9 +278,6 @@ func (screen *UnixScreen) onWindowResized() {
 //
 // See also: https://github.com/walles/moor/issues/53
 func terminalHasArrowKeysEmulation() bool {
-	// Untested:
-	// * The Windows terminal
-
 	// Better off with mouse tracking:
 	// * iTerm2 (macOS)
 	// * Terminal.app (macOS)
@@ -372,6 +369,13 @@ func terminalHasArrowKeysEmulation() bool {
 		return true
 	}
 
+	// Windows Terminal, tested here:
+	// https://github.com/walles/moor/issues/53#issuecomment-3276404279
+	if os.Getenv("WT_SESSION") != "" {
+		log.Info("Windows Terminal detected, assuming arrow keys emulation active")
+		return true
+	}
+
 	log.Info("No known terminal with arrow keys emulation detected, assuming mouse tracking is needed")
 	return false
 }
